/**
 * @file create_mission_XML.cpp
 * @author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * @brief sets mission steps for create mission XML's standard mission
 * @version 0.1
 * @date 2024-08-30
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#include <memory>
#include <map>
#include <string>
#include <vector>

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include "create_mission_xml.h"
#include "standard_mission/standard_mission/standard_mission.h"

/**
 * @brief Construct a new create_mission_xml:: create_mission_xml object
 * 
 * @param toolName entry from toolinfo.h
 * @param toolVersion entry from toolinfo.h
 */
create_mission_xml::create_mission_xml(const int argc, char *argv[], const std::string &toolName,
                                 const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
    std::string mission_type = EndnodeReadOnly<std::string>("program_settings/mission_selector").read(rtIO_->moduleConfig).value();
    if (mission_type != "design_mission" && mission_type != "study_mission" && mission_type != "requirements_mission") {
        throwError(__FILE__, __func__, __LINE__, "Specified mission '" + mission_type +
                "' is unkown! Only use 'design_mission', 'study_mission' or 'requirements_mission'. Abort program!");
    }
    route_ = {mission_type}; // By now, only one level depth vector
    missionStrategy_.setStrategy(missionSelection_(route_)(rtIO_));
}

strategyaccess create_mission_xml::missionSelection_(const std::vector<std::string> &route) {
    /* Routing table */
    std::map<std::string, strategyaccess> table = {
        {"design_mission",       [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<design_mission::standard_mission>(arg); }},
        {"study_mission",        [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<study_mission::standard_mission>(arg); }},
        {"requirements_mission", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<requirements_mission::standard_mission>(arg); }}
    };
    return table[route.at(0)];
}
