/**
 * @file main.cpp
 * @author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * @brief Main for create mission XML
 * @version 0.1
 * @date 2024-08-30
 * 
 * @copyright Copyright (c) 2024
 * 
 */
/* The following statements import necessary specific header files*/
#include "toolinfo.h"
#include "create_mission_xml.h"

int main(int argc, char *argv[]) {
    try {
        create_mission_xml create_mission_xml(argc, argv, TOOL_NAME, TOOL_VERSION);
        return create_mission_xml.execute();

     /* Catch: Trigger: if a C++ code specific error occurs */
    } catch (const char * text) {
        if (myRuntimeInfo == nullptr) {
            std::cerr << text << std::endl;
        } else {
            myRuntimeInfo->err << text << std::endl;
            delete myRuntimeInfo;
        }
        exit(1);

    /* Catch: Trigger: if a C++ code specific error occurs */
    } catch (const std::string& text) {
        if (myRuntimeInfo == nullptr) {
            std::cerr << text << std::endl;
        } else {
            myRuntimeInfo->err << text << std::endl;
            delete myRuntimeInfo;
        }
        exit(1);

    /* Catch: Trigger: if an error in c++ standard libraries occurs -> C++ standard error will occurred */
    } catch (const std::exception& e) {
        if (myRuntimeInfo == nullptr) {
            std::cerr << "The following C++ standard error has occurred: " << e.what() << std::endl;
        } else {
            myRuntimeInfo->err << "The following C++ standard error has occurred: " << e.what() << std::endl;
            delete myRuntimeInfo;
        }
        exit(1);

    /* Catch: Trigger: if any other error occurs */
    } catch (...) {
         if (myRuntimeInfo == nullptr) {
            std::cerr << "An uncaught error has occurred - Exit." << std::endl;
        } else {
            myRuntimeInfo->err << "An uncaught error has occurred - Exit." << std::endl;
            delete myRuntimeInfo;
        }
        exit(1);
    }
}
